@@ -11,6 +11,7 @@ from .classifiers import (
     MaxP,
     NaturalBreaks,
     Percentiles,
+    PrettyBreaks,
     Quantiles,
     StdMean,
     UserDefined,
@@ -33,6 +34,7 @@ _classifiers = {
     "naturalbreaks": NaturalBreaks,
     "quantiles": Quantiles,
     "percentiles": Percentiles,
+    "prettybreaks": PrettyBreaks,
     "stdmean": StdMean,
     "userdefined": UserDefined,
 }
@@ -50,6 +52,8 @@ def classify(
     mindiff=0,
     initial=100,
     bins=None,
+    lowest=None,
+    anchor=False,
 ):
     """
 
@@ -89,6 +93,14 @@ def classify(
         :math:`(k,1)`, upper bounds of classes (have to be monotically
         increasing) if using ``user_defined`` classifier.
         Default is ``None``. For example: ``[20, max(y)]``.
+    lowest : float (default None)
+        Scalar minimum value of lowest class. Default is to set the minimum
+        to ``-inf`` if  ``y.min()`` > first upper bound (which will override
+        the default), otherwise minimum is set to ``y.min()``.
+    anchor : bool (default False)
+            Anchor upper bound of one class to the sample mean.
+
+
 
     Returns
     -------
@@ -103,20 +115,21 @@ def classify(
     Supported classifiers include:
 
     * ``quantiles``
-    * ``box_plot``
-    * ``equal_interval``
-    * ``fisher_jenks``
-    * ``fisher_jenks_sampled``
-    * ``headtail_breaks``
-    * ``jenks_caspall``
-    * ``jenks_caspall_sampled``
-    * ``jenks_caspall_forced``
-    * ``max_p``
-    * ``maximum_breaks``
-    * ``natural_breaks``
+    * ``boxplot``
+    * ``equalinterval``
+    * ``fisherjenks``
+    * ``fisherjenkssampled``
+    * ``headtailbreaks``
+    * ``jenkscaspall``
+    * ``jenkscaspallsampled``
+    * ``jenks_caspallforced``
+    * ``maxp``
+    * ``maximumbreaks``
+    * ``naturalbreaks``
     * ``percentiles``
-    * ``std_mean``
-    * ``user_defined``
+    * ``prettybreaks``
+    * ``stdmean``
+    * ``userdefined``
 
     Examples
     --------
@@ -176,7 +189,7 @@ def classify(
         classifier = _classifiers[scheme](y, pct)
 
     elif scheme == "stdmean":
-        classifier = _classifiers[scheme](y, multiples)
+        classifier = _classifiers[scheme](y, multiples, anchor)
 
     elif scheme == "jenkscaspallsampled":
         classifier = _classifiers[scheme](y, k, pct_sampled)
@@ -188,7 +201,7 @@ def classify(
         classifier = _classifiers[scheme](y, k, initial)
 
     elif scheme == "userdefined":
-        classifier = _classifiers[scheme](y, bins)
+        classifier = _classifiers[scheme](y, bins, lowest)
 
     elif scheme in [
         "equalinterval",
@@ -196,6 +209,7 @@ def classify(
         "jenkscaspall",
         "jenkscaspallforced",
         "quantiles",
+        "prettybreaks",
     ]:
         classifier = _classifiers[scheme](y, k)
 
